argsbuilder

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2020 License: MPL-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewBlacklistError

func NewBlacklistError(s string) error

NewBlacklistError returns a BlackListError.

Types

type Args

type Args map[Key]Value

Args represents a set of args.

func (Args) Args

func (a Args) Args() []string

Args implements the ArgsBuilder interface.

func (Args) Contains

func (a Args) Contains(k Key) bool

Contains checks if an arg key exists.

func (Args) Get

func (a Args) Get(k Key) Value

Get returns an args value.

func (Args) Merge

func (a Args) Merge(args Args) ArgsBuilder

Merge implements the ArgsBuilder interface.

func (Args) Set

func (a Args) Set(k, v Key) ArgsBuilder

Set implements the ArgsBuilder interface.

type ArgsBuilder

type ArgsBuilder interface {
	Merge(Args) ArgsBuilder
	Set(string, string) ArgsBuilder
	Args() []string
}

ArgsBuilder defines the requirements to build and manage a set of args.

type BlackListError

type BlackListError struct {
	// contains filtered or unexported fields
}

BlackListError represents an error indicating that an argument was supplied that is not allowed.

func (*BlackListError) Error

func (b *BlackListError) Error() string

Error implements the Error interface.

type Key

type Key = string

Key represents an arg key.

type Value

type Value = string

Value represents an arg value.

Jump to