Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBlacklistError ¶
NewBlacklistError returns a BlackListError.
Types ¶
type Args ¶
Args represents a set of args.
func (Args) Merge ¶
func (a Args) Merge(args Args) ArgsBuilder
Merge implements the ArgsBuilder interface.
type ArgsBuilder ¶
type ArgsBuilder interface {
Merge(Args) ArgsBuilder
Set(string, string) ArgsBuilder
Args() []string
}
ArgsBuilder defines the requirements to build and manage a set of args.
type BlackListError ¶
type BlackListError struct {
// contains filtered or unexported fields
}
BlackListError represents an error indicating that an argument was supplied that is not allowed.
func (*BlackListError) Error ¶
func (b *BlackListError) Error() string
Error implements the Error interface.
Click to show internal directories.
Click to hide internal directories.