Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DNSNames ¶ added in v0.3.0
DNSNames returns a default set of machine names. It includes the hostname, and FQDN if the kernel domain name is set. If the kernel domain name is not set, only the hostname is included in the set.
func DomainName ¶ added in v0.3.0
DomainName returns the kernel domain name. If a domain name is not found, an empty string is returned.
func FormatAddress ¶
FormatAddress checks that the address has a consistent format.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.